BackendInitAttemptFailure class

Failure details for a single FFI backend initialization attempt.

Constructors

BackendInitAttemptFailure({required PreferredBackend backend, required Object error, required StackTrace stackTrace})
const

Properties

backend PreferredBackend
Backend used for this initialization attempt.
final
error Object
Error reported while initializing backend.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace
Stack trace captured with error.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited