FlutterAssetLoader class
Stub class - should never be instantiated on web platform
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyAssetToFile(
String assetPath, String targetPath) → Future< void> -
copyAssetToFileWithProgress(
String assetPath, String targetPath) → Stream< int> -
loadAsset(
String path) → Future< Uint8List> -
Loads an asset as bytes from the given path
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited