WebCacheService class

Stub implementation for non-web platforms

Constructors

WebCacheService(dynamic cacheInterop, dynamic prefs, dynamic fileSystem, {bool enableCache = true})

Properties

enableCache → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cacheModel(String url, Uint8List data) → Future<void>
clearCache() → Future<void>
getCachedBlobUrl(String url) → Future<String?>
getCachedUrls() → Future<List<String>>
getOrCacheAndRegister({required String cacheKey, required Future<Uint8List> loader(), required String targetPath}) → Future<String>
getOrCacheAndRegisterWithProgress({required String cacheKey, required Future<Uint8List> loader(void onProgress(double)), required String targetPath}) → Stream<int>
getStorageQuota() → Future<StorageQuota>
isCached(String url) → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPersistentStorage() → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited