LiteRtLayoutMsvc class final

LiteRtLayout as packed by MSVC. Used on Windows only.

Inheritance
Implemented types
Available extensions

Constructors

LiteRtLayoutMsvc()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
boolStorageUnit int
getter/setter pair
dimensions Array<Int32>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pad0 int
getter/setter pair
pad1 int
getter/setter pair
pad2 int
getter/setter pair
rankAndHasStrides int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strides Array<Uint32>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited