OrphanedFileInfo class
Information about a potentially orphaned file
Constructors
Properties
- filename → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDownloadFragment → bool
-
final
- lastModified → DateTime?
-
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeBytes → int
-
final
- sizeMB → double
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited