ParallelFunctionCallResponse class

Multiple function calls in a single model response.

Inheritance

Constructors

ParallelFunctionCallResponse({required List<FunctionCallResponse> calls})
const

Properties

calls List<FunctionCallResponse>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited