Distance enum

Distance metric used by a qdrant-edge shard. Set at open time and fixed for the shard's lifetime.

Inheritance
Available extensions

Values

cosine → const Distance

1 - cosine angle between vectors. Most common for text embeddings; expects (but does not require) unit-norm inputs.

const Distance('cosine')
dot → const Distance

Dot product. For unit-norm vectors equivalent to cosine.

const Distance('dot')
euclid → const Distance

Euclidean (L2) distance.

const Distance('euclid')
manhattan → const Distance

Manhattan (L1) distance.

const Distance('manhattan')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Distance>
A constant List of the values in this enum, in order of their declaration.