EmbeddingRegistry class

Holds embedding backends registered via FlutterGemma.initialize. Same probe-chain selection as EngineRegistry.

Properties

hasAny → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
registered → List<EmbeddingBackendProvider>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

findFor(EmbeddingModelSpec spec) → EmbeddingBackendProvider?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerAll(List<EmbeddingBackendProvider> backends) → void
reset() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → EmbeddingRegistry
final