modelPath property
The file the compiled model opens. Compared instead of the spec NAME, which is what the shells compared before: reinstalling a same-named model to a new path was invisible to them.
Implementation
final String modelPath;
The file the compiled model opens. Compared instead of the spec NAME, which is what the shells compared before: reinstalling a same-named model to a new path was invisible to them.
final String modelPath;