ModelInfo class

Model metadata stored in repository

Constructors

ModelInfo({required String id, required ModelSource source, required DateTime installedAt, required int sizeBytes, required ModelType type, required bool hasLoraWeights})
const
ModelInfo.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasLoraWeights → bool
final
id → String
final
installedAt → DateTime
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes → int
final
source → ModelSource
final
type → ModelType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited