stopGeneration abstract method

Future<void> stopGeneration()

Stops the current generation, cancelling native decoding on the .litertlm FFI path. Call this (or cancel() the response subscription) whenever a streamed response is superseded or no longer needed.

Implementation

Future<void> stopGeneration();