TaskType enum

Task type for embedding generation, following Google RAG SDK convention.

EmbeddingGemma models are trained with different prefixes for queries and documents to improve retrieval quality.

Inheritance
Available extensions

Values

retrievalQuery → const TaskType

For search queries. Prepends query prefix before embedding.

retrievalDocument → const TaskType

For document indexing. Prepends document prefix before embedding.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TaskType>
A constant List of the values in this enum, in order of their declaration.