PartConverter<T extends Part> class
A converter that converts a JSON map to a Part.
- Inheritance
-
- Object
- JsonToPartConverter<
T> - PartConverter
- Annotations
Constructors
-
PartConverter(_JsonToPartFunction<
T> _function) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bind(
Stream< Map< stream) → Stream<String, Object?> >T> -
Transforms the provided
stream.inherited -
cast<
RS, RT> () → Converter< RS, RT> -
Provides a
Converter<RS, RT>view of this stream transformer.inherited -
convert(
Map< String, Object?> input) → T -
Converts
inputand returns the result of the conversion.override -
fuse<
TT> (Converter< T, TT> other) → Converter<Map< String, Object?> , TT> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startChunkedConversion(
Sink< T> sink) → Sink<Map< String, Object?> > -
Starts a chunked conversion.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited