defaultPartConverterRegistry top-level constant

Map<String, JsonToPartConverter<Part>> const defaultPartConverterRegistry

Converter registry for parts in this package.

The key of a map entry is the part type. The value is the converter that knows how to convert that part type.

To add support for additional part types, extend this map.

To limit supported part types, or to remove support for part types in future versions of genai_primitives, define a new map.

Implementation

const Map<String, JsonToPartConverter<Part>> defaultPartConverterRegistry =
    _standardPartConverterRegistry;