DocumentWithEmbedding class

Document with embedding for HNSW rebuild

Used by getAllDocumentsWithEmbeddings to return documents with their vectors for in-memory index reconstruction.

Constructors

DocumentWithEmbedding({required String id, required String content, required List<double> embedding, String? metadata})

Properties

content String
getter/setter pair
embedding List<double>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
metadata String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) DocumentWithEmbedding