BackendInitException class
Exception thrown after every FFI backend fallback attempt fails.
- Implemented types
Constructors
-
BackendInitException({required Iterable<
BackendInitAttemptFailure> attempts})
Properties
-
attempts
→ List<
BackendInitAttemptFailure> -
Failed backend attempts in the order they were tried.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastAttempt → BackendInitAttemptFailure
-
Last backend attempt, usually the most actionable failure.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited