FunctionCallParser class
Facade for backward compatibility. Delegates to model-specific FunctionCallFormat implementations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isDefinitelyText(
String buffer, {ModelType? modelType}) → bool - Checks if buffer looks definitely like text (not a function call)
-
isFunctionCallComplete(
String buffer, {ModelType? modelType}) → bool - Check if function call structure is complete
-
isFunctionCallStart(
String buffer, {ModelType? modelType}) → bool - Check if buffer starts with function call indicators
-
isJsonComplete(
String buffer) → bool - DEPRECATED: Use isFunctionCallComplete instead
-
isJsonStart(
String buffer) → bool - DEPRECATED: Use isFunctionCallStart instead
-
parse(
String text, {ModelType? modelType}) → FunctionCallResponse? - Parse a single function call based on model type
-
parseAll(
String text, {ModelType? modelType}) → List< FunctionCallResponse> - Parse all function calls from text (for parallel tool calls)