AlignedAlloc class

Pair of (raw, aligned) pointers returned by allocAligned.

Constructors

AlignedAlloc(Pointer<Uint8> raw, Pointer<Uint8> aligned)

Properties

aligned Pointer<Uint8>
A pointer into raw aligned to the requested boundary. Use this for the LiteRT C API; do not free it directly.
final
hashCode int
The hash code for this object.
no setterinherited
raw Pointer<Uint8>
The actual calloc-owned allocation. Free with calloc.free(raw).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited