TtsRelativeSuffix class
A relative path segment appended to the install base URL (the plain
basename itself, or a tables//voices/ subpath for qwen3's
embedding-table/demo-voice members).
- Inheritance
-
- Object
- TtsFetchLocation
- TtsRelativeSuffix
Constructors
- TtsRelativeSuffix(String suffix)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override