core/utils/host_native_library library
Functions
-
firstExistingPath(
List< String> candidates) → String? - First candidate that exists, as an absolute path, or null.
-
hostNativeCacheBase(
) → String? - Root the Native Assets hooks cache downloaded bundles under.
-
hostNativeDirName(
) → String? -
Host platform subdirectory used by both the hooks' cache layout and the
in-repo
prebuilt/trees. -
hostNativeLibraryCandidates(
{required String libFileName, String? envOverride, String? cacheNamespace, List< String> relativePaths = const [], int walkUpLevels = 8}) → List<String> - Every path to try for a host-side native library, in order.
-
hostNativeLibraryFileName(
String baseName) → String -
Platform-correct file name for a library called
baseName.